using System;
using UnityEngine;
using HutongGames.PlayMaker;

namespace PixelCrushers.DialogueSystem.PlayMaker {
	
	[ActionCategory("Dialogue System")]
	[HutongGames.PlayMaker.TooltipAttribute("Starts a conversation with support for up to four additional conversants.")]
	public class StartConversation : FsmStateAction {
		
		[RequiredField]
		[HutongGames.PlayMaker.TooltipAttribute("The conversation to start")]
		public FsmString conversation;

		[HutongGames.PlayMaker.TooltipAttribute("The starting dialogue entry ID. Leave at -1 to start at the beginning")]
		public FsmInt startingEntryID;
		
		[HutongGames.PlayMaker.TooltipAttribute("The primary actor (usually Player)")]
		public FsmGameObject actor;

        [HutongGames.PlayMaker.TooltipAttribute("The first conversant (usually NPC)")]
        public FsmGameObject conversant;

        [HutongGames.PlayMaker.TooltipAttribute("The second conversant (defaults to NPC2)")]
        public FsmGameObject conversant2;

        [HutongGames.PlayMaker.TooltipAttribute("The third conversant (defaults to NPC3)")]
        public FsmGameObject conversant3;

        [HutongGames.PlayMaker.TooltipAttribute("The fourth conversant (defaults to NPC4)")]
        public FsmGameObject conversant4;

        [HutongGames.PlayMaker.TooltipAttribute("The fifth conversant (defaults to NPC5)")]
        public FsmGameObject conversant5;

        public override void Reset() {
			if (conversation != null) conversation.Value = string.Empty;
			startingEntryID = new FsmInt();
			startingEntryID.Value = -1;
			if (actor != null) actor.Value = null;
            if (conversant != null) conversant.Value = null;
            if (conversant2 != null) conversant2.Value = null;
            if (conversant3 != null) conversant3.Value = null;
            if (conversant4 != null) conversant4.Value = null;
            if (conversant5 != null) conversant5.Value = null;
        }

        public override void OnEnter() {
			string conversationTitle = (conversation != null) ? conversation.Value : string.Empty;
			Transform actorTransform = ((actor != null) && (actor.Value != null)) ? actor.Value.transform : null;
            Transform conversantTransform = ((conversant != null) && (conversant.Value != null)) ? conversant.Value.transform : null;

            Transform conversant2Transform = ((conversant2 != null) && (conversant2.Value != null)) ? conversant2.Value.transform : null;
            Transform conversant3Transform = ((conversant3 != null) && (conversant3.Value != null)) ? conversant3.Value.transform : null;
            Transform conversant4Transform = ((conversant4 != null) && (conversant4.Value != null)) ? conversant4.Value.transform : null;
            Transform conversant5Transform = ((conversant5 != null) && (conversant5.Value != null)) ? conversant5.Value.transform : null;
            CharacterInfo.RegisterActorTransform("NPC2", conversant2Transform);
            CharacterInfo.RegisterActorTransform("NPC3", conversant3Transform);
            CharacterInfo.RegisterActorTransform("NPC4", conversant4Transform);
            CharacterInfo.RegisterActorTransform("NPC5", conversant5Transform);

            if (actorTransform == null) LogWarning(string.Format("{0}: PlayMaker Action Start Conversation - actor is null", DialogueDebug.Prefix));
            if (string.IsNullOrEmpty(conversationTitle)) LogWarning(string.Format("{0}: PlayMaker Action Start Conversation - conversation title is blank", DialogueDebug.Prefix));
            var entryID = (startingEntryID != null) ? startingEntryID.Value : -1;
            DialogueManager.StartConversation(conversationTitle, actorTransform, conversantTransform, entryID);
            Finish();
		}
		
	}
	
}